# HERBS
A toolkit for Histological E-data Registration in Brain Space


## Install

```python
$ pip install herbs
```

## Usage

```python
import herbs
herbs.run_herbs()
```

<img src="./herbs.jpg" width="800px"></img>
